pub struct InputSignatureRef<'a>(/* private fields */);Expand description
A borrowed equivalent of the InputSignature data type.
It can be useful for checking incoming signatures from unauthorized sources.
Examples
use secp256k1::Secp256k1;
use btc_transaction_utils::InputSignatureRef;
// Get a signature from the unknown source.
let bytes = hex::decode(
"304402201538279618a4626653775069b43d4315c7d2ff3000\
8d339d0ed31ff41e628e71022028f3182fc39df28201ca4d7d\
489aece7bc5bc6bfe05b09b6a9d3b70bf5f3743101",
).unwrap();
// Try to decode it.
let signature = InputSignatureRef::from_bytes(&bytes)
.expect("Signature should be correct");Implementations
Sourceimpl<'a> InputSignatureRef<'a>
impl<'a> InputSignatureRef<'a>
Sourcepub fn from_bytes(bytes: &'a [u8]) -> Result<InputSignatureRef<'a>, Error>
pub fn from_bytes(bytes: &'a [u8]) -> Result<InputSignatureRef<'a>, Error>
Tries to construct input signature from the raw bytes.
Sourcepub fn sighash_type(&self) -> SigHashType
pub fn sighash_type(&self) -> SigHashType
Returns a sighash type of the given input signature.